@@ -20,7 +20,8 @@ class ChatterBot(IPlugin):
         now = datetime.now()
         return {"plugin": "ChatterBot",
                 "method": "getTime",
-                "body": now.strftime(self._('time'))
+                "body": now.strftime(self._('It is %(hour)s:%(minute)s' % {'hour': '%H',
+                                                                           'minute': '%M'}))
         }
 
     def sayHello(self, jsonInput):
